# Example Package

Welcome to Mahdi Zare's Machine Learning Library. With the help of this package, you can create machine learning models and algorithms.
Included preprocessing, training, evaluation, and so on.
This module is similar to the sikit learn package.